@@ -1,12 +1,24 @@
-def sub_coords(offset, coord):
-    """
-    Finds the relative coordinate of one point in another point
+import pygame
 
-    :param coord: the coordinate
-    :param offset: the coordinate relative to
 
+def add_vector(a, b):
     """
-    return (coord[0] - offset[0], coord[1] - offset[1])
+    Adds two vectors (a+b)
+
+    :param a:
+    :param b:
+    """
+    return (a[0] + b[0], a[1] + b[1])
+
+
+def sub_vector(a, b):
+    """
+    Subtracts two vectors (a-b)
+
+    :param a:
+    :param b:
+    """
+    return (a[0] - b[0], a[1] - b[1])
 
 
 def translate(value, min1, max1, min2, max2):
@@ -23,10 +35,25 @@ def translate(value, min1, max1, min2, max2):
     span2 = max2 - min2
     if span1 == 0:
         return 0
+    if value == None:
+        return None
     valueScaled = float(value - min1) / float(span1)
     return min2 + (valueScaled * span2)
 
 
+def get_default_font():
+    font_name = pygame.font.get_fonts()[0]
+    return pygame.font.SysFont(font_name, 20)
+
+
+def clip(value, min1, max1):
+    return max(min1, min(max1, value))
+
+
+def float_format(n, exponent):
+    return str(n) if exponent < 0 else str(int(n))
+
+
 WHITE = (255, 255, 255)
 """
 Preset for the color White
@@ -47,7 +74,11 @@ BLACK = (0, 0, 0)
 """
 Preset for the color Black
 """
-GREY = (230, 230, 230)
+LIGHT_GREY = (230, 230, 230)
+"""
+Preset for the color Light Grey
+"""
+GREY = (200, 200, 200)
 """
 Preset for the color Grey
 """
@@ -59,3 +90,7 @@ ORANGE = (255, 100, 0)
 """
 Preset for the color Orange
 """
+TRANSPARENT = (0, 0, 0, 0)
+"""
+Preset for transparent (for alpha surfaces)
+"""
